@@ -9,7 +9,7 @@ from sklearn.model_selection import train_test_split
 from category_encoders import OrdinalEncoder
 
 from shapash.data.data_loader import data_loading
-from shapash.explainer.smart_explainer import SmartExplainer
+from shapash import SmartExplainer
 
 house_df, house_dict = data_loading('house_prices')
 y_df = house_df['SalePrice'].to_frame()
@@ -29,16 +29,15 @@ regressor = LGBMRegressor(n_estimators=200).fit(Xtrain, ytrain)
 
 y_pred = pd.DataFrame(regressor.predict(Xtest), columns=['pred'], index=Xtest.index)
 
-xpl = SmartExplainer(features_dict=house_dict)
-
-xpl.compile(
-    x=Xtest,
+xpl = SmartExplainer(
     model=regressor,
+    features_dict=house_dict,
     preprocessing=encoder,
-    y_pred=y_pred,
     title_story='House Prices - Lightgbm Regressor'
 )
 
+xpl.compile(x=Xtest, y_pred=y_pred)
+
 xpl.init_app()
 app = xpl.smartapp.app
 
